@@ -1,10 +1,11 @@
 import unittest
 
-from nose.tools import assert_equal, assert_list_equal, nottest, raises
+#from nose.tools import assert_equal, assert_list_equal, nottest, raises
 from py_stringmatching.tokenizer.delimiter_tokenizer import DelimiterTokenizer
 from py_stringmatching.tokenizer.qgram_tokenizer import QgramTokenizer
 import numpy as np
 import pandas as pd
+from .utils import raises
 
 from py_stringsimjoin.filter.position_filter import PositionFilter
 from py_stringsimjoin.utils.converter import dataframe_column_to_str
@@ -112,13 +113,13 @@ class FilterPairTestCases(unittest.TestCase):
         self.test_filter_pair('', '', self.dlm, 'JACCARD', 0.8,
                               True, False, False)
 
-    @nottest
+    @unittest.skip("Not a test")
     def test_filter_pair(self, lstring, rstring, tokenizer, sim_measure_type,
                          threshold, allow_empty, allow_missing, expected_output):
         position_filter = PositionFilter(tokenizer, sim_measure_type, threshold,
                                          allow_empty, allow_missing)
         actual_output = position_filter.filter_pair(lstring, rstring)
-        assert_equal(actual_output, expected_output)
+        self.assertEqual(actual_output, expected_output)
 
 
 # test PositionFilter.filter_tables method
@@ -297,7 +298,7 @@ class FilterTablesTestCases(unittest.TestCase):
                                 'id', 'id', 'attr', 'attr'),
                                 expected_pairs)
 
-    @nottest
+    @unittest.skip("Not a test")
     def test_filter_tables(self, tokenizer, sim_measure_type, threshold,
                            allow_empty, allow_missing, args, expected_pairs):
         position_filter = PositionFilter(tokenizer, sim_measure_type, threshold,
@@ -333,7 +334,7 @@ class FilterTablesTestCases(unittest.TestCase):
                     expected_output_attrs.append(r_out_prefix + attr)
 
         # verify whether the output table has the necessary attributes.
-        assert_list_equal(list(actual_candset.columns.values),
+        self.assertListEqual(list(actual_candset.columns.values),
                           expected_output_attrs)
 
         actual_pairs = set()
@@ -342,9 +343,9 @@ class FilterTablesTestCases(unittest.TestCase):
                                        str(row[r_out_prefix + args[3]]))))
 
         # verify whether the actual pairs and the expected pairs match.
-        assert_equal(len(expected_pairs), len(actual_pairs))
+        self.assertEqual(len(expected_pairs), len(actual_pairs))
         common_pairs = actual_pairs.intersection(expected_pairs)
-        assert_equal(len(common_pairs), len(expected_pairs))
+        self.assertEqual(len(common_pairs), len(expected_pairs))
 
 
 # test PositionFilter.filter_candset method
@@ -423,7 +424,7 @@ class FilterCandsetTestCases(unittest.TestCase):
                                 'l_id', 'r_id', 'l_attr', 'r_attr'),
                                 expected_pairs)
 
-    @nottest
+    @unittest.skip("Not a test")
     def test_filter_candset(self, tokenizer, sim_measure_type, threshold,
                             allow_empty, allow_missing, args, expected_pairs):
         position_filter = PositionFilter(tokenizer, sim_measure_type, threshold,
@@ -431,7 +432,7 @@ class FilterCandsetTestCases(unittest.TestCase):
         actual_output_candset = position_filter.filter_candset(*args)
 
         # verify whether the output table has the necessary attributes.
-        assert_list_equal(list(actual_output_candset.columns.values),
+        self.assertListEqual(list(actual_output_candset.columns.values),
                           list(args[0].columns.values))
 
         actual_pairs = set()
@@ -439,9 +440,9 @@ class FilterCandsetTestCases(unittest.TestCase):
             actual_pairs.add(','.join((str(row[args[1]]), str(row[args[2]]))))
 
         # verify whether the actual pairs and the expected pairs match.
-        assert_equal(len(expected_pairs), len(actual_pairs))
+        self.assertEqual(len(expected_pairs), len(actual_pairs))
         common_pairs = actual_pairs.intersection(expected_pairs)
-        assert_equal(len(common_pairs), len(expected_pairs))
+        self.assertEqual(len(common_pairs), len(expected_pairs))
 
 
 class PositionFilterInvalidTestCases(unittest.TestCase):
